<?php
/**
 * Featured Story Section options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

// Add Featured Story section
$wp_customize->add_section( 'magazinews_pro_featured_story_section', array(
	'title'             => esc_html__( 'Featured Story Slider','magazinews-pro' ),
	'description'       => esc_html__( 'Featured Story Section options.', 'magazinews-pro' ),
	'panel'             => 'magazinews_pro_front_page_panel',
) );

// Featured Story content enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_section_enable]', array(
	'default'			=> 	$options['featured_story_section_enable'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[featured_story_section_enable]', array(
	'label'             => esc_html__( 'Featured Story Section Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_featured_story_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_count]', array(
	'default'          	=> $options['featured_story_count'],
	'sanitize_callback' => 'magazinews_pro_sanitize_number_range',
	'validate_callback' => 'magazinews_pro_validate_featured_story_count',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[featured_story_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'magazinews-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_featured_story_section',
	'active_callback'   => 'magazinews_pro_is_featured_story_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Featured Story content type control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_content_type]', array(
	'default'          	=> $options['featured_story_content_type'],
	'sanitize_callback' => 'magazinews_pro_sanitize_select',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[featured_story_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_featured_story_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazinews_pro_is_featured_story_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magazinews-pro' ),
		'post' 		=> esc_html__( 'Post', 'magazinews-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazinews-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_story_count']; $i++ ) :
	// featured_story pages drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_content_page_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[featured_story_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_featured_story_section',
		'choices'			=> magazinews_pro_page_choices(),
		'active_callback'	=> 'magazinews_pro_is_featured_story_section_content_page_enable',
	) ) );

	// featured_story posts drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_content_post_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[featured_story_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_featured_story_section',
		'choices'			=> magazinews_pro_post_choices(),
		'active_callback'	=> 'magazinews_pro_is_featured_story_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[featured_story_content_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazinews_pro_theme_options[featured_story_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_featured_story_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazinews_pro_is_featured_story_section_content_category_enable'
) ) );

// featured story btn title setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_story_readmore'],
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[featured_story_readmore]', array(
	'label'           	=> esc_html__( 'Readmore Label', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_featured_story_section',
	'active_callback' 	=> 'magazinews_pro_is_featured_story_section_enable',
	'type'				=> 'text',
) );

// featured story image setting and control.
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_ads]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'magazinews_pro_theme_options[featured_story_ads]',
		array(
		'label'       		=> esc_html__( 'Ads Image', 'magazinews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'magazinews-pro' ), 1920, 250 ),
		'section'     		=> 'magazinews_pro_featured_story_section',
		'active_callback'	=> 'magazinews_pro_is_featured_story_section_enable',
) ) );

// featured story ads alt setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_ads_alt]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[featured_story_ads_alt]', array(
	'label'           	=> esc_html__( 'Ads Image Alt Text', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_featured_story_section',
	'active_callback' 	=> 'magazinews_pro_is_featured_story_section_enable',
	'type'				=> 'text',
) );

// featured story ads url setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[featured_story_ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[featured_story_ads_url]', array(
	'label'           	=> esc_html__( 'Ads Image Url', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_featured_story_section',
	'active_callback' 	=> 'magazinews_pro_is_featured_story_section_enable',
	'type'				=> 'url',
) );
