<?php
/**
 * Trending Section options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

// Add Trending section
$wp_customize->add_section( 'magazinews_pro_trending_section', array(
	'title'             => esc_html__( 'Trending','magazinews-pro' ),
	'description'       => esc_html__( 'Trending Section options.', 'magazinews-pro' ),
	'panel'             => 'magazinews_pro_front_page_panel',
) );

// Trending content enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[trending_section_enable]', array(
	'default'			=> 	$options['trending_section_enable'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[trending_section_enable]', array(
	'label'             => esc_html__( 'Trending Section Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_trending_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
) ) );

// trending title setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[trending_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[trending_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_trending_section',
	'active_callback' 	=> 'magazinews_pro_is_trending_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazinews_pro_theme_options[trending_title]', array(
		'selector'            => '#recent-posts .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'magazinews_pro_theme_options[trending_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'magazinews_pro_trending_title_partial',
    ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[trending_content_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazinews_pro_theme_options[trending_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest five posts will be shown from each selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_trending_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazinews_pro_is_trending_section_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[trending_content_sidebar_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Category_Control( $wp_customize,'magazinews_pro_theme_options[trending_content_sidebar_category]', array(
	'label'             => esc_html__( 'Select Sidebar Categories', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select not more than three categories. Latest five posts will be shown from each selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_trending_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'magazinews_pro_is_trending_section_enable',
) ) );
