<?php
/**
 * Trending section
 *
 * This is the template for the content of trending section
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */
if ( ! function_exists( 'magazinews_pro_add_trending_section' ) ) :
    /**
    * Add trending section
    *
    *@since Magazinews Pro 1.0.0
    */
    function magazinews_pro_add_trending_section() {
    	$options = magazinews_pro_get_theme_options();
        // Check if trending is enabled on frontpage
        $trending_enable = apply_filters( 'magazinews_pro_section_status', true, 'trending_section_enable' );

        if ( true !== $trending_enable ) {
            return false;
        }
        // Get trending section details
        $section_details = array();
        $section_details = apply_filters( 'magazinews_pro_filter_trending_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render trending section now.
        magazinews_pro_render_trending_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazinews_pro_get_trending_section_details' ) ) :
    /**
    * trending section details.
    *
    * @since Magazinews Pro 1.0.0
    * @param array $input trending section details.
    */
    function magazinews_pro_get_trending_section_details( $input ) {
        $options = magazinews_pro_get_theme_options();

        $main_cat = ! empty( $options['trending_content_category'] ) ? $options['trending_content_category'] : '';
        $sidebar_cat = ! empty( $options['trending_content_sidebar_category'] ) ? $options['trending_content_sidebar_category'] : array();
        $content = array();
        $content['main'] = array();
        $content['sidebar'] = array();
        $content['sidebar_cat'] = array();

        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 5,
            'cat'               => absint( $main_cat ),
            'ignore_sticky_posts'   => true,
            );   

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = magazinews_pro_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content['main'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $sidebar_cat ) ) :
            $sidebar_cat = array_slice($sidebar_cat, 0, 3);
            $i = 0;
            foreach ( $sidebar_cat as $cat ) :
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 5,
                    'cat'               => absint( $cat ),
                    'ignore_sticky_posts'   => true,
                    );  

                // Push to the main array.
                array_push( $content['sidebar_cat'], $cat );    
                $content['sidebar'][$i] = array();

                // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post[$i]['id']    = get_the_id();
                        $page_post['auth_id']   = get_the_author_meta('ID');
                        $page_post[$i]['title'] = get_the_title();
                        $page_post[$i]['url']   = get_the_permalink();
                        $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : '';

                        // Push to the main array.
                        array_push( $content['sidebar'][$i], $page_post[$i] );
                    endwhile;
                endif;

                wp_reset_postdata();  
                $i++;           
            endforeach;
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending section content details.
add_filter( 'magazinews_pro_filter_trending_section_details', 'magazinews_pro_get_trending_section_details' );


if ( ! function_exists( 'magazinews_pro_render_trending_section' ) ) :
  /**
   * Start trending section
   *
   * @return string trending content
   * @since Magazinews Pro 1.0.0
   *
   */
   function magazinews_pro_render_trending_section( $content_details = array() ) {
        $options = magazinews_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="recent-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper">
                    <?php if ( ! empty( $options['trending_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['trending_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <div class="section-content-wrapper col-2 clear">
                    <div class="recent-posts-tabs clear">
                        <ul class="tabs recent-posts-nav">
                            <?php $i = 1; foreach ( $content_details['main'] as $content ) : ?>
                                <li data-tab="recent-post-<?php echo absint( $content['id'] ); ?>" <?php echo ( $i == 1 ) ? 'class="active"' : ''; ?>>
                                    <article>
                                        <div class="recent-post-wrapper">
                                            <div class="nav-number"><span><?php echo absint( $i ); ?></span></div><!-- .nav-number -->

                                            <div class="entry-container">
                                                <header class="entry-header">
                                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                </header>

                                                <div class="entry-meta">
                                                    <?php magazinews_pro_posted_on( $content['id'] ); ?> 
                                                </div><!-- .entry-meta -->
                                            </div><!-- .entry-container -->
                                        </div><!-- .recent-post-wrapper -->
                                    </article>
                                </li>
                            <?php $i++; endforeach; ?>
                        </ul><!-- .recent-posts-nav -->

                        <div class="recent-posts-wrapper">
                            <?php $i = 1; foreach ( $content_details['main'] as $content ) : ?>
                                <article id="recent-post-<?php echo absint( $content['id'] ); ?>" class="tab-content <?php echo ( $i == 1 ) ? 'active' : ''; ?>" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] );  ?></a></h2>
                                        </header>

                                        <div class="entry-meta">
                                            <?php  
                                                magazinews_pro_posted_on( $content['id'] );
                                                echo magazinews_pro_author( $content['auth_id'] );
                                            ?>
                                        </div><!-- .entry-meta -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </article>
                            <?php $i++; endforeach; ?>
                        </div><!-- .recent-posts-wrapper -->
                    </div><!-- .recent-posts-tabs -->

                    <?php if ( ! empty( $content_details['sidebar_cat'] ) ) : ?>
                        <div class="recent-reviews-wrapper">
                            <ul class="tabs recent-reviews-nav clear">
                                <?php $i = 1; foreach ( $content_details['sidebar_cat'] as $cat ) : ?>
                                    <li data-tab="trending-sidebar-<?php echo absint( $content ); ?>" <?php echo ( $i == 1 ) ? 'class="active"' : ''; ?>><?php echo esc_html( get_cat_name( $cat ) ); ?></li>
                                <?php $i++; endforeach; ?>
                            </ul><!-- .recent-reviews-nav -->

                            <div class="recent-post-reviews-wrapper">
                                <ul>
                                    <?php $i = 0; foreach ( $content_details['sidebar'] as $content_detail ) : ?>
                                        <li id="trending-sidebar-<?php echo absint( $content_details['sidebar_cat'][$i] ); ?>" class="tab-content <?php echo ( $i == 0 ) ? 'active' : ''; ?>">
                                            <?php foreach ( $content_detail as $content ) : ?>
                                                <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail ">
                                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                                        </div><!-- .featured-image -->
                                                    <?php endif; ?>

                                                    <div class="entry-container">
                                                        <header class="entry-header">
                                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                        </header>

                                                        <div class="entry-meta">
                                                            <?php magazinews_pro_posted_on( $content['id'] ); ?>  
                                                        </div><!-- .entry-meta -->
                                                    </div><!-- .entry-container -->
                                                </article>
                                            <?php endforeach; ?>
                                        </li>
                                    <?php $i++; endforeach; ?>
                                    
                                </ul><!-- .tabs -->
                                
                            </div><!-- .recent-post-reviews-wrapper -->
                        </div><!-- .recent-reviews-wrapper -->
                    <?php endif; ?>
                </div><!-- .section-content-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #recent-posts -->

    <?php }
endif;